@@ -148,6 +148,7 @@ public:
 
     SV *message_descriptor() const;
     SV *make_object(SV *data) const;
+    bool get_decode_blessed() const;
 
 private:
     bool encode(upb::Sink *sink, upb::Status *status, SV *ref) const;
@@ -189,7 +190,7 @@ private:
     upb::Sink encoder_sink, decoder_sink;
     std::string output_buffer;
     upb::StringSink string_sink;
-    bool check_required_fields, decode_explicit_defaults, encode_defaults, check_enum_values;
+    bool check_required_fields, decode_explicit_defaults, encode_defaults, check_enum_values, decode_blessed;
     WarnContext *warn_context;
 };
 
